@@ -214,7 +214,7 @@ brasero_tool_dialog_run (BraseroToolDialog *self)
 	cursor = gdk_cursor_new (GDK_WATCH);
 	window = gtk_widget_get_window (GTK_WIDGET (self));
 	gdk_window_set_cursor (window, cursor);
-	gdk_cursor_unref (cursor);
+	g_object_unref (cursor);
 
 	gtk_button_set_label (GTK_BUTTON (priv->cancel), GTK_STOCK_CANCEL);
 
@@ -529,8 +529,6 @@ brasero_tool_dialog_init (BraseroToolDialog *obj)
 
 	priv = BRASERO_TOOL_DIALOG_PRIVATE (obj);
 
-	gtk_dialog_set_has_separator (GTK_DIALOG (obj), FALSE);
-
 	/* upper part */
 	priv->upper_box = gtk_vbox_new (FALSE, 0);
 	gtk_widget_show (GTK_WIDGET (priv->upper_box));
